.. vkgdr documentation master file, created by
   sphinx-quickstart on Mon Feb 21 14:38:51 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to vkgdr's documentation!
=================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   intro
   c_api
   python_api
   changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
